@@ -261,7 +261,7 @@ module Octokit
       # @return [Sawyer::Resource] The specific comment in question
       # @see https://developer.github.com/v3/issues/comments/#get-a-single-comment
       # @example Get comment #1194549 from an issue on octokit/octokit.rb
-      #   Octokit.issue_comments("octokit/octokit.rb", 1194549)
+      #   Octokit.issue_comment("octokit/octokit.rb", 1194549)
       def issue_comment(repo, number, options = {})
         paginate "#{Repository.path repo}/issues/comments/#{number}", options
       end
@@ -317,6 +317,17 @@ module Octokit
         paginate "#{Repository.path repo}/issues/#{number}/timeline", options
       end
 
+      # Lists the available assignees for issues in a repository.
+      #
+      # @param repo [Integer, String, Repository, Hash] A GitHub repository
+      # @return [Array<Sawyer::Resource>] List of GitHub users.
+      # @see https://developer.github.com/v3/issues/assignees/#list-assignees
+      # @example Get available assignees on repository octokit/octokit.rb
+      #   Octokit.list_assignees("octokit/octokit.rb")
+      def list_assignees(repo, options = {})
+        paginate "#{Repository.path repo}/assignees", options
+      end
+
       # Add assignees to an issue
       #
       # @param repo [Integer, String, Repository, Hash] A GitHub repository
@@ -329,6 +340,24 @@ module Octokit
       def add_assignees(repo, number, assignees, options = {})
         post "#{Repository.path repo}/issues/#{number}/assignees", options.merge({:assignees => assignees})
       end
+
+      # Remove assignees from an issue
+      #
+      # @param repo [Integer, String, Repository, Hash] A GitHub repository
+      # @param number [Integer] Issue number
+      # @param assignees [Array] Assignees to be removed
+      # @param options [Hash] Header params for request
+      # @return [Sawyer::Resource] Issue
+      # @see https://developer.github.com/v3/issues/assignees/#remove-assignees-from-an-issue
+      # @example Remove assignees "pengwynn" and "joeyw" from Issue #23 on octokit/octokit.rb
+      #   Octokit.remove_assignees("octokit/octokit.rb", 23, ["pengwynn", "joeyw"])
+      #
+      # @example Remove assignees "pengwynn" from Issue #23 on octokit/octokit.rb
+      #   Octokit.remove_assignees("octokit/octokit.rb", 23, ["pengwynn"],
+      #     :accept => "application/vnd.github.v3+json")
+      def remove_assignees(repo, number, assignees, options = {})
+        delete "#{Repository.path repo}/issues/#{number}/assignees", options.merge({:assignees => assignees})
+      end
     end
   end
 end
